@@ -9,7 +9,7 @@ import transaction
 from dateutil.relativedelta import relativedelta
 
 from pyramid_celery import celery_app
-from sqlalchemy import or_, desc, func
+from sqlalchemy import or_, desc, func, extract
 from collections import OrderedDict
 from datetime import date
 
@@ -981,84 +981,67 @@ def get_current_exercice_dates(upload_date):
 
 
 def collect_operations_by_fiscal_year(
-    upload_id: int, data_type: str, upload_date: datetime.date
+    upload_id: int, upload_date: datetime.date, exclude_future_operations: bool = False
 ) -> List[AccountingOperation]:
     """
     Return the operations needed.
     Collect the operations ("écritures") according to the "exercice fiscal".
     If the "exercice" has been set "closed" in enDI we don't collect the
-    operation of former year (because à-nouveau operation have been done by
+    operation of former years (because à-nouveau operation have been done by
     the accountant.
-    For now, this function is only for the treasury meausures, in the future
+    For now, this function is only for the treasury measures, in the future
     it might also be for the income statement measure.
     """
-    logger.debug("  + Collecting operations for upload : {}".format(upload_id))
+    logger.info(
+        "  + Collecting operations for {} (upload_id={})".format(
+            upload_date.year, upload_id
+        )
+    )
 
+    # Get current exercice dates
     (
         current_exercice_begining_date,
         current_exercice_end_date,
     ) = get_current_exercice_dates(upload_date)
 
-    # Pour la tréso on ne prend pas les écritures dans le futur
-    # ATTENTION : Pour l'instant _collect_operations() n'est que pour la tréso
-    # mais si elle est utilisé pour d'autres états il faudra filtrer ici
-    max_operation_date = min(current_exercice_end_date, date.today())
+    # Compute first operation date (through former exercices)
+    first_operation_date = current_exercice_begining_date
+    first_exercice = (
+        DBSESSION().query(extract("year", func.min(AccountingOperation.date))).scalar()
+    )
+    previous_exercice = upload_date.year - 1
+    for exercice in range(previous_exercice, first_exercice - 1, -1):
+        exercice_closure = AccountingClosure.query().filter_by(year=exercice).first()
+        closure_is_done = exercice_closure.active if exercice_closure else False
+        if closure_is_done:
+            # Stop on first closure
+            break
+        else:
+            first_operation_date = current_exercice_begining_date - relativedelta(
+                years=(upload_date.year - exercice)
+            )
 
-    current_exercice_operations = (
+    # Compute last operation date (exclude future operations if needed)
+    last_operation_date = current_exercice_end_date
+    if exclude_future_operations:
+        last_operation_date = min(current_exercice_end_date, date.today())
+
+    # Collect operations on computed period
+    logger.info(
+        "    + Date range is from {} to {}".format(
+            first_operation_date, last_operation_date
+        )
+    )
+    collected_operations = (
         AccountingOperation.query()
         .filter(
-            AccountingOperation.date.between(
-                current_exercice_begining_date, max_operation_date
-            )
+            AccountingOperation.date.between(first_operation_date, last_operation_date)
         )
         .all()
     )
+    logger.info("    + {} operations collected".format(len(collected_operations)))
 
-    logger.debug(
-        "    + {} operations collected".format(len(current_exercice_operations))
-    )
-
-    # Adding last exercice operations if needed
-    # if data_type != AccountingOperationUpload.SYNCHRONIZED_ACCOUNTING:
-    #     return current_exercice_operations
-
-    # Has the closure been done for former year ?
-    former_closure_year = upload_date.year - 1
-    former_year_closure = (
-        AccountingClosure.query().filter_by(year=former_closure_year).first()
-    )
-
-    closure_is_done = False
-    if former_year_closure:
-        closure_is_done = former_year_closure.active
-
-    logger.info(f"    + {former_closure_year} closure is done ?: {closure_is_done}")
-
-    if not closure_is_done:
-        last_exercice_begining_date = current_exercice_begining_date - relativedelta(
-            years=1
-        )
-        last_exercice_end_date = current_exercice_end_date - relativedelta(years=1)
-
-        last_exercice_operations = (
-            AccountingOperation.query()
-            .filter(
-                AccountingOperation.date.between(
-                    last_exercice_begining_date, last_exercice_end_date
-                )
-            )
-            .all()
-        )
-
-        logger.info(
-            "    + Appending {} operations from last exercice".format(
-                len(last_exercice_operations)
-            )
-        )
-
-        return last_exercice_operations + current_exercice_operations
-
-    return current_exercice_operations
+    return collected_operations
 
 
 def collect_operations(
@@ -1077,7 +1060,7 @@ def collect_operations(
         return AccountingOperation.query().filter_by(upload_id=upload.id)
     else:
         return collect_operations_by_fiscal_year(
-            upload.id, upload.filetype, upload.date
+            upload.id, upload.date, exclude_future_operations=True
         )
 
 
