@@ -25,6 +25,10 @@ from sqlalchemy import (
     Boolean,
     DateTime,
     Date,
+    Integer,
+    BigInteger,
+    Float,
+    Numeric,
 )
 from sqlalchemy.orm import (
     RelationshipProperty,
@@ -38,7 +42,7 @@ from endi_base.utils import (
     ascii,
     date as date_utils,
 )
-
+from endi.compute import math_utils
 from endi_celery.exception import (
     MissingMandatoryArgument,
     MultipleInstanceFound,
@@ -59,7 +63,7 @@ avec la valeur {1}"
 NO_ID_KEY_ERROR = "Une entrée n'a pas de valeur pour la clé {0}."
 UNFILLED_VALUES = ("", None, 0)
 
-BOOLEAN_FALSE = ("0", "false", "non", "", "False")
+BOOLEAN_FALSE = ("0", "false", "non", "", "False", "N", "Non", "NON", "NO")
 DATETIME_FORMAT = "%d/%m/%Y"
 
 
@@ -144,7 +148,7 @@ def format_input_value(value, sqla_column_dict, force_rel_creation=False):
             res = sqla_column_dict["formatter"](value)
 
         elif isinstance(column_type, Boolean):
-            if value in ("0", "false", "non", "", "False"):
+            if value in BOOLEAN_FALSE:
                 res = False
             else:
                 res = True
@@ -157,6 +161,11 @@ def format_input_value(value, sqla_column_dict, force_rel_creation=False):
             ),
         ):
             res = date_utils.str_to_date(value)
+
+        elif isinstance(column_type, (Integer, BigInteger)):
+            res = math_utils.str_to_int(value, default=None)
+        elif isinstance(column_type, (Numeric, Float)):
+            res = math_utils.str_to_float(value, default=None)
     return res
 
 
@@ -503,6 +512,8 @@ class CsvImporter(object):
             args[key] = value
 
         logger.debug("Inserting {}".format(args))
+        if "id" in args:
+            args.pop("id")
         model = self.factory(**args)
         if persist:
             self.dbsession.add(model)
@@ -675,7 +686,7 @@ class CsvImporter(object):
             log.exception("Erreur lors de l'import de données")
             self.in_error_lines.append(line)
             res = None
-            message = e.message
+            message = str(e)
         return res, message
 
     def gen_csv_str(self, datas):
