@@ -54,8 +54,8 @@ def async_mail_salarysheets(self, job_id, mails, force):
         }
     :param force: Should we force the mail sending
     """
-    logger.info(u"We are launching an asynchronous mail sending operation")
-    logger.info(u"  The job id : %s" % job_id)
+    logger.info("We are launching an asynchronous mail sending operation")
+    logger.info("  The job id : %s" % job_id)
 
     from endi_base.models.base import DBSESSION
 
@@ -77,13 +77,13 @@ def async_mail_salarysheets(self, job_id, mails, force):
             email = mail_datas["email"]
 
             if email is None:
-                logger.error(u"no mail found for company {0}".format(company_id))
+                logger.error("no mail found for company {0}".format(company_id))
                 continue
             else:
                 message = mail_datas["message"]
                 subject = mail_datas["subject"]
-                logger.info(u"  The mail subject : %s" % subject)
-                logger.info(u"  The mail message : %s" % message)
+                logger.info("  The mail subject : %s" % subject)
+                logger.info("  The mail message : %s" % message)
 
                 mail_history = send_salary_sheet(
                     request,
@@ -102,40 +102,40 @@ def async_mail_salarysheets(self, job_id, mails, force):
         except MailAlreadySent:
             transaction.abort()
             error_count += 1
-            msg = u"Ce fichier a déjà été envoyé {0}".format(mail_datas["attachment"])
+            msg = "Ce fichier a déjà été envoyé {0}".format(mail_datas["attachment"])
             error_messages.append(msg)
-            logger.exception(u"Mail already delivered")
-            logger.error(u"* Part of the Task FAILED")
+            logger.exception("Mail already delivered")
+            logger.error("* Part of the Task FAILED")
             continue
 
         except UndeliveredMail:
             transaction.abort()
             error_count += 1
-            msg = u"Impossible de délivrer de mail à l'entreprise {0} \
+            msg = "Impossible de délivrer de mail à l'entreprise {0} \
 (mail : {1})".format(
                 company_id, email
             )
             error_messages.append(msg)
-            logger.exception(u"Unable to deliver an e-mail")
-            logger.error(u"* Part of the Task FAILED")
+            logger.exception("Unable to deliver an e-mail")
+            logger.error("* Part of the Task FAILED")
             continue
 
         except Exception as e:
             transaction.abort()
             error_count += 1
-            logger.exception(u"The subtransaction has been aborted")
-            logger.error(u"* Part of the task FAILED !!!")
-            error_messages.append(u"{0}".format(e))
+            logger.exception("The subtransaction has been aborted")
+            logger.error("* Part of the task FAILED !!!")
+            error_messages.append("{0}".format(e))
 
         else:
             mail_count += 1
-            logger.info(u"The transaction has been commited")
-            logger.info(u"* Part of the Task SUCCEEDED !!!")
+            logger.info("The transaction has been commited")
+            logger.info("* Part of the Task SUCCEEDED !!!")
 
-    messages = [u"{0} mails ont été envoyés".format(mail_count)]
-    messages.append(u"{0} mails n'ont pas pu être envoyés".format(error_count))
+    messages = ["{0} mails ont été envoyés".format(mail_count)]
+    messages.append("{0} mails n'ont pas pu être envoyés".format(error_count))
 
-    logger.info(u"-> Task finished")
+    logger.info("-> Task finished")
     if error_count > 0:
         utils.record_failure(
             MailingJob,
